"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Gotenberg = void 0;
const tslib_1 = require("tslib");
process.env.SUPPRESS_NO_CONFIG_WARNING = 'y';
const dotenv = tslib_1.__importStar(require("dotenv"));
const path = tslib_1.__importStar(require("path"));
const config_1 = tslib_1.__importDefault(require("config"));
// Load endpoint from environment-specific file (e.g., .env.development)
const envFile = `.env.${process.env.NODE_ENV}`;
const envFileFallback = '.env';
const dotenvConfig = dotenv.config({ path: path.resolve(envFile) });
// Fallback to loading the default environment file.
if (dotenvConfig.error) {
    dotenv.config({ path: path.resolve(envFileFallback) });
}
/**
 * Class representing configuration for interacting with Gotenberg service.
 */
class Gotenberg {
    /**
     * The endpoint for the Gotenberg service.
     * @type {string}
     */
    static get endpoint() {
        return (process.env.GOTENBERG_ENDPOINT ||
            config_1.default.get('gotenberg.endpoint'));
    }
    /**
     * The username for basic authentication with the Gotenberg service.
     * @type {string | undefined}
     */
    static get username() {
        const hasUsername = config_1.default.has('gotenberg.api.basicAuth.username');
        return hasUsername
            ? config_1.default.get('gotenberg.api.basicAuth.username')
            : process.env.GOTENBERG_API_BASIC_AUTH_USERNAME;
    }
    /**
     * The password for basic authentication with the Gotenberg service.
     * @type {string | undefined}
     */
    static get password() {
        const hasPassword = config_1.default.has('gotenberg.api.basicAuth.password');
        return hasPassword
            ? config_1.default.get('gotenberg.api.basicAuth.password')
            : process.env.GOTENBERG_API_BASIC_AUTH_PASSWORD;
    }
}
exports.Gotenberg = Gotenberg;
//# sourceMappingURL=gotenberg.js.map