"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.LibreOffice = void 0;
const tslib_1 = require("tslib");
const form_data_1 = tslib_1.__importDefault(require("form-data"));
const main_config_1 = require("../main.config");
const common_1 = require("../common");
const libre_office_utils_1 = require("./utils/libre-office.utils");
/**
 * Class representing a LibreOffice for various operations such as merging and conversion.
 */
class LibreOffice {
    /**
     * Converts various document formats to PDF.
     *
     * @param {Object} options - Options for the conversion operation.
     * @param {PathLikeOrReadStream[]} options.files - An array of PathLikes or ReadStreams to the files to be converted to PDF.
     * @param {PageProperties} [options.properties] - Page properties for the conversion.
     * @param {pdfa} [options.pdfFormat] - PDF format options.
     * @param {boolean} [options.pdfUA] - Indicates whether to generate PDF/UA compliant output.
     * @param {boolean} [options.merge] - Indicates whether to merge the resulting PDFs.
     * @returns {Promise<Buffer>} A Promise resolving to the converted PDF content as a Buffer.
     */
    static convert(_a) {
        return tslib_1.__awaiter(this, arguments, void 0, function* ({ files, properties, pdfa, pdfUA, merge, metadata }) {
            const data = new form_data_1.default();
            yield libre_office_utils_1.LibreOfficeUtils.addFiles(files, data);
            yield libre_office_utils_1.LibreOfficeUtils.customize(data, {
                properties,
                merge,
                pdfa,
                pdfUA,
                metadata
            });
            const endpoint = `${main_config_1.Chromiumly.GOTENBERG_ENDPOINT}/${main_config_1.Chromiumly.LIBRE_OFFICE_PATH}/${main_config_1.Chromiumly.LIBRE_OFFICE_ROUTES.convert}`;
            return common_1.GotenbergUtils.fetch(endpoint, data, main_config_1.Chromiumly.GOTENBERG_API_BASIC_AUTH_USERNAME, main_config_1.Chromiumly.GOTENBERG_API_BASIC_AUTH_PASSWORD);
        });
    }
}
exports.LibreOffice = LibreOffice;
//# sourceMappingURL=libre-office.js.map